@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: GeometryGraphOperation.h 2556 2009-06-06 22:22:28Z strk $
+ * $Id: GeometryGraphOperation.h 2958 2010-03-29 11:29:40Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -26,6 +26,11 @@
 
 #include <vector>
 
+#ifdef _MSC_VER
+#pragma warning(push)
+#pragma warning(disable: 4251) // warning C4251: needs to have dll-interface to be used by clients of class
+#endif
+
 // Forward declarations
 namespace geos {
 	namespace algorithm {
@@ -79,6 +84,10 @@ protected:
 } // namespace geos.operation
 } // namespace geos
 
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
+
 #endif
 
 /**********************************************************************
